package com.ruoyi.ibs.list.service;


import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.ibs.list.domain.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 分群客户关联关系,导入的客群用户存放在这里Service接口
 *
 * @author ruoyi
 * @date 2024-09-14
 */
public interface ISysGroupCustomerService {
    /**
     * 查询分群客户关联关系,导入的客群用户存放在这里
     *
     * @param id 分群客户关联关系,导入的客群用户存放在这里主键
     * @return 分群客户关联关系, 导入的客群用户存放在这里
     */
    public SysGroupCustomer selectSysGroupCustomerById(Long id);

    /**
     * 查询分群客户关联关系,导入的客群用户存放在这里列表
     *
     * @param sysGroupCustomer 分群客户关联关系,导入的客群用户存放在这里
     * @return 分群客户关联关系, 导入的客群用户存放在这里集合
     */
    public List<SysGroupCustomer> selectSysGroupCustomerList(SysGroupCustomer sysGroupCustomer);

    /**
     * 查询分群客户关联关系,导入的客群用户存放在这里列表
     *
     * @param sysGroupCustomer 分群客户关联关系,导入的客群用户存放在这里
     * @return 分群客户关联关系, 导入的客群用户存放在这里集合
     */
    public void selectSysGroupCustomerListExport(HttpServletResponse response, String groupId,String pushStatus);


    public void selectSysGroupCustomerListDetailExport(HttpServletResponse response, String groupId);

    public void convertExport(HttpServletResponse response, List<CustomerList> list, List<SysGroupCustomerExportVo> customerExportVos, List<SysGroupMerchantExportVo> merchantExportVos, List<SysGroupBusinessExportVo> businessExportVos, String groupType);

    public void convertExport1(HttpServletResponse response, List<CustomerList> list, List<SysGroupCustomerExportVo> customerExportVos, List<SysGroupMerchantExportVo> merchantExportVos, List<SysGroupBusinessExportVo> businessExportVos, String groupType, String exportType);
    /**
     * 根据客户id列表查询客群客户
     *
     * @param sysGroupCustomer 分群客户关联关系,导入的客群用户存放在这里
     * @return 分群客户关联关系,导入的客群用户存放在这里集合
     */
    public void selectSysGroupCustomerListExportByCustIds(HttpServletResponse response,String groupId,List<String> custIds, String exportType);

    /**
     * 新增分群客户关联关系,导入的客群用户存放在这里
     *
     * @param sysGroupCustomer 分群客户关联关系,导入的客群用户存放在这里
     * @return 结果
     */
    public int insertSysGroupCustomer(SysGroupCustomer sysGroupCustomer);

    /**
     * 修改分群客户关联关系,导入的客群用户存放在这里
     *
     * @param sysGroupCustomer 分群客户关联关系,导入的客群用户存放在这里
     * @return 结果
     */
    public int updateSysGroupCustomer(SysGroupCustomer sysGroupCustomer);

    /**
     * 批量删除分群客户关联关系,导入的客群用户存放在这里
     *
     * @param ids 需要删除的分群客户关联关系,导入的客群用户存放在这里主键集合
     * @return 结果
     */
    public int deleteSysGroupCustomerByIds(Long[] ids);

    /**
     * 删除分群客户关联关系,导入的客群用户存放在这里信息
     *
     * @param id 分群客户关联关系,导入的客群用户存放在这里主键
     * @return 结果
     */
    public int deleteSysGroupCustomerById(Long id);

    /**
     *
     * @param groupId
     * @return
     */
    public int updateOutletsIdAndUserIdByUsername(String groupId);

    public int updateCustIdAndCustIsn(String groupId,String custType,List<String> custIdcs);

    public int updateCustIdAndCustIsnBySocialCreditCode(String groupId,String custType,List<String> socialCreditCodes);

    /**
     *
     * @param sysGroupCustomers
     * @return
     */
    public int insertSysGroupCustomerBatch(List<SysGroupCustomer> sysGroupCustomers);

    public String selectCustIdcBySocialCreditCode(String custType,String socialCreditCode);

}
